@@ -58,7 +58,7 @@ from tinydav.exception import HTTPError, HTTPUserError, HTTPServerError
 
 __author__ = "Manuel Hermann <manuel-hermann@gmx.net>"
 __license__ = "LGPL"
-__version__ = "0.7.0"
+__version__ = "0.7.1"
 
 __all__ = (
     "HTTPError", "HTTPUserError", "HTTPServerError",
@@ -759,7 +759,9 @@ class HTTPClient(object):
         if headers:
             sendheaders.update(headers)
         for (key, value) in sendheaders.items():
-            if key.lower() != "authorization":
+            try:
+                unicode(value).encode("ascii")
+            except UnicodeError:
                 value = str(Header(value, default_header_encoding))
             sendheaders[key] = value
         # construct query string
